@@ -10,10 +10,6 @@ import json
 from enum import Enum
 from typing import TYPE_CHECKING, Annotated, Any, Literal, NewType, Optional, Union, get_args
 
-import packaging
-import packaging.tags
-import packaging.utils
-import packaging.version
 import sigstore.errors
 from annotated_types import MinLen  # noqa: TCH002
 from cryptography import x509
@@ -27,14 +23,12 @@ from pydantic_core import ValidationError
 from sigstore._utils import _sha256_streaming
 from sigstore.dsse import DigestSet, StatementBuilder, Subject, _Statement
 from sigstore.dsse import Envelope as DsseEnvelope
-from sigstore.errors import Error as SigstoreError
-from sigstore.models import Bundle
-from sigstore.models import TransparencyLogEntry as _TransparencyLogEntry
+from sigstore.dsse import Error as DsseError
+from sigstore.models import Bundle, LogEntry
 from sigstore.sign import ExpiredCertificate, ExpiredIdentity
 from sigstore.verify import Verifier, policy
-from sigstore_models.intoto import Envelope as _Envelope
-from sigstore_models.intoto import Signature as _Signature
-from sigstore_models.rekor.v1 import TransparencyLogEntry as _TransparencyLogEntryInner
+from sigstore_protobuf_specs.io.intoto import Envelope as _Envelope
+from sigstore_protobuf_specs.io.intoto import Signature as _Signature
 
 if TYPE_CHECKING:  # pragma: no cover
     from pathlib import Path
@@ -97,8 +91,7 @@ class Distribution(BaseModel):
     @field_validator("name")
     @classmethod
     def _validate_name(cls, v: str) -> str:
-        _check_dist_filename(v)
-        return v
+        return _ultranormalize_dist_filename(v)
 
     @classmethod
     def from_file(cls, dist: Path) -> Distribution:
@@ -200,7 +193,7 @@ class Attestation(BaseModel):
                 .predicate_type(AttestationType.PYPI_PUBLISH_V1)
                 .build()
             )
-        except SigstoreError as e:
+        except DsseError as e:
             raise AttestationError(str(e))
 
         try:
@@ -237,7 +230,6 @@ class Attestation(BaseModel):
         dist: Distribution,
         *,
         staging: bool = False,
-        offline: bool = False,
     ) -> tuple[str, Optional[dict[str, Any]]]:
         """Verify against an existing Python distribution.
 
@@ -249,9 +241,6 @@ class Attestation(BaseModel):
         `staging` parameter can be toggled to enable the staging verifier
         instead.
 
-        If `offline` is `True`, the verifier will not attempt to refresh the
-        TUF repository.
-
         On failure, raises an appropriate subclass of `AttestationError`.
         """
         # NOTE: Can't do `isinstance` with `Publisher` since it's
@@ -264,9 +253,9 @@ class Attestation(BaseModel):
             policy = identity
 
         if staging:
-            verifier = Verifier.staging(offline=offline)
+            verifier = Verifier.staging()
         else:
-            verifier = Verifier.production(offline=offline)
+            verifier = Verifier.production()
 
         bundle = self.to_bundle()
         try:
@@ -290,24 +279,14 @@ class Attestation(BaseModel):
             raise VerificationError("invalid subject: missing name")
 
         try:
-            # We don't allow signing of malformed distribution names.
-            # Previous versions of this package went further than this
-            # and "ultranormalized" the name, but this was superfluous
-            # and caused confusion for users who expected the subject to
-            # be an exact match for their distribution filename.
-            # See: https://github.com/pypi/warehouse/issues/18128
-            # See: https://github.com/pypi/pypi-attestations/issues/123
-            parsed_subject_name = _check_dist_filename(subject.name)
+            # We always ultranormalize when signing, but other signers may not.
+            subject_name = _ultranormalize_dist_filename(subject.name)
         except ValueError as e:
             raise VerificationError(f"invalid subject: {str(e)}")
 
-        # NOTE: Cannot fail, since we validate the `Distribution` name
-        # on construction.
-        parsed_dist_name = _check_dist_filename(dist.name)
-
-        if parsed_subject_name != parsed_dist_name:
+        if subject_name != dist.name:
             raise VerificationError(
-                f"subject does not match distribution name: {subject.name} != {dist.name}"
+                f"subject does not match distribution name: {subject_name} != {dist.name}"
             )
 
         digest = subject.digest.root.get("sha256")
@@ -329,9 +308,9 @@ class Attestation(BaseModel):
 
         evp = DsseEnvelope(
             _Envelope(
-                payload=base64.b64encode(statement),
+                payload=statement,
                 payload_type=DsseEnvelope._TYPE,  # noqa: SLF001
-                signatures=[_Signature(sig=base64.b64encode(signature))],
+                signatures=[_Signature(sig=signature)],
             )
         )
 
@@ -342,8 +321,7 @@ class Attestation(BaseModel):
             raise ConversionError("invalid X.509 certificate") from err
 
         try:
-            inner = _TransparencyLogEntryInner.from_dict(tlog_entry)
-            log_entry = _TransparencyLogEntry(inner)
+            log_entry = LogEntry._from_dict_rekor(tlog_entry)  # noqa: SLF001
         except (ValidationError, sigstore.errors.Error) as err:
             raise ConversionError("invalid transparency log entry") from err
 
@@ -362,9 +340,6 @@ class Attestation(BaseModel):
 
         envelope = sigstore_bundle._inner.dsse_envelope  # noqa: SLF001
 
-        if not envelope:
-            raise ConversionError("bundle does not contain a DSSE envelope")
-
         if len(envelope.signatures) != 1:
             raise ConversionError(f"expected exactly one signature, got {len(envelope.signatures)}")
 
@@ -373,7 +348,7 @@ class Attestation(BaseModel):
             verification_material=VerificationMaterial(
                 certificate=base64.b64encode(certificate),
                 transparency_entries=[
-                    sigstore_bundle.log_entry._inner.to_dict()  # noqa: SLF001
+                    sigstore_bundle.log_entry._to_rekor().to_dict()  # noqa: SLF001
                 ],
             ),
             envelope=Envelope(
@@ -405,23 +380,12 @@ def _der_decode_utf8string(der: bytes) -> str:
     return der_decode(der, UTF8String)[0].decode()  # type: ignore[no-any-return]
 
 
-_SdistName = tuple[packaging.utils.NormalizedName, packaging.version.Version]
-_BdistName = tuple[
-    packaging.utils.NormalizedName,
-    packaging.version.Version,
-    packaging.utils.BuildTag,
-    frozenset[packaging.tags.Tag],
-]
-_DistName = Union[_SdistName, _BdistName]
+def _ultranormalize_dist_filename(dist: str) -> str:
+    """Return an "ultranormalized" form of the given distribution filename.
 
-
-def _check_dist_filename(dist: str) -> _DistName:
-    """Validate a distribution filename for well-formedness.
-
-    This does **not** fully normalize the filename. For example,
-    a user can include a non-normalized version string or package name
-    (or compressed tag set in the case of wheels), and this function
-    will **not** reject so long as it parses correctly.
+    This form is equivalent to the normalized form for sdist and wheel
+    filenames, with the additional stipulation that compressed tag sets,
+    if present, are also sorted alphanumerically.
 
     Raises `ValueError` on any invalid distribution filename.
     """
@@ -429,10 +393,44 @@ def _check_dist_filename(dist: str) -> _DistName:
     # already rejects non-lowercase variants.
     if dist.endswith(".whl"):
         # `parse_wheel_filename` raises a supertype of ValueError on failure.
-        return parse_wheel_filename(dist)
+        name, ver, build, tags = parse_wheel_filename(dist)
+
+        # The name has been normalized to replace runs of `[.-_]+` with `-`,
+        # which then needs to be replaced with `_` for the wheel.
+        name = name.replace("-", "_")
+
+        # `parse_wheel_filename` normalizes the name and version for us,
+        # so all we need to do is re-compress the tag set in a canonical
+        # order.
+        # NOTE(ww): This is written in a not very efficient manner, since
+        # I wasn't feeling smart.
+        impls, abis, platforms = set(), set(), set()
+        for tag in tags:
+            impls.add(tag.interpreter)
+            abis.add(tag.abi)
+            platforms.add(tag.platform)
+
+        impl_tag = ".".join(sorted(impls))
+        abi_tag = ".".join(sorted(abis))
+        platform_tag = ".".join(sorted(platforms))
+
+        if build:
+            parts = "-".join(
+                [name, str(ver), f"{build[0]}{build[1]}", impl_tag, abi_tag, platform_tag]
+            )
+        else:
+            parts = "-".join([name, str(ver), impl_tag, abi_tag, platform_tag])
+
+        return f"{parts}.whl"
     elif dist.endswith((".tar.gz", ".zip")):
         # `parse_sdist_filename` raises a supertype of ValueError on failure.
-        return parse_sdist_filename(dist)
+        name, ver = parse_sdist_filename(dist)
+        name = name.replace("-", "_")
+
+        if dist.endswith(".tar.gz"):
+            return f"{name}-{ver}.tar.gz"
+        else:
+            return f"{name}-{ver}.zip"
     else:
         raise ValueError(f"unknown distribution format: {dist}")
 
@@ -489,31 +487,18 @@ class _GitHubTrustedPublisherPolicy:
         raw_build_config_uri = _der_decode_utf8string(build_config_uri.value.public_bytes())
 
         # (2) Extract the source repo digest and ref.
-        # We require at least one of these to be present.
-        suffixes = []
-        try:
-            source_repo_digest = cert.extensions.get_extension_for_oid(
-                policy._OIDC_SOURCE_REPOSITORY_DIGEST_OID  # noqa: SLF001
-            )
-            suffixes.append(_der_decode_utf8string(source_repo_digest.value.public_bytes()))
-        except x509.ExtensionNotFound:
-            pass
+        source_repo_digest = cert.extensions.get_extension_for_oid(
+            policy._OIDC_SOURCE_REPOSITORY_DIGEST_OID  # noqa: SLF001
+        )
+        sha = _der_decode_utf8string(source_repo_digest.value.public_bytes())
 
-        try:
-            source_repo_ref = cert.extensions.get_extension_for_oid(
-                policy._OIDC_SOURCE_REPOSITORY_REF_OID  # noqa: SLF001
-            )
-            suffixes.append(_der_decode_utf8string(source_repo_ref.value.public_bytes()))
-        except x509.ExtensionNotFound:
-            pass
-
-        if not suffixes:
-            raise sigstore.errors.VerificationError(
-                "Certificate must contain either Source Repository Digest or Source Repository Ref"
-            )
+        source_repo_ref = cert.extensions.get_extension_for_oid(
+            policy._OIDC_SOURCE_REPOSITORY_REF_OID  # noqa: SLF001
+        )
+        ref = _der_decode_utf8string(source_repo_ref.value.public_bytes())
 
         # (3)-(4): Build the expected URIs and compare them
-        for suffix in suffixes:
+        for suffix in [sha, ref]:
             expected = (
                 f"https://github.com/{self._repository}/.github/workflows/{self._workflow}@{suffix}"
             )
@@ -646,22 +631,7 @@ class GitLabPublisher(_PublisherBase):
         return _GitLabTrustedPublisherPolicy(self.repository, self.workflow_filepath)
 
 
-class GooglePublisher(_PublisherBase):
-    """A Google Cloud-based Trusted Publisher."""
-
-    kind: Literal["Google"] = "Google"
-
-    email: str
-    """
-    The email address of the Google Cloud service account that performed
-    the publishing action.
-    """
-
-    def _as_policy(self) -> VerificationPolicy:
-        return policy.Identity(identity=self.email, issuer="https://accounts.google.com")
-
-
-_Publisher = Union[GitHubPublisher, GitLabPublisher, GooglePublisher]
+_Publisher = Union[GitHubPublisher, GitLabPublisher]
 Publisher = Annotated[_Publisher, Field(discriminator="kind")]
 
 
